﻿namespace CPUInfoDemo
{
    using System;
    using System.Collections.Generic;
    using System.Diagnostics;
    using System.IO;

    using Microsoft.VisualBasic.Devices;

    class Utility : IDisposable
    {
      
        readonly PerformanceCounter cpu;

        readonly ComputerInfo cinf;

        public Utility()
        {
            this.cpu = new PerformanceCounter("Processor", "% Processor Time", "_Total");
            this.cinf = new ComputerInfo();
        }

        public double GetCpuPercent()
        {
            var percentage = this.cpu.NextValue();
            return   Math.Round(percentage, 2, MidpointRounding.AwayFromZero);
        }

        public double GetMemoryPercent()
        {
            var usedMem = this.cinf.TotalPhysicalMemory - this.cinf .AvailablePhysicalMemory ;//总内存减去可用内存
          return   Math.Round(
                   (double)(usedMem / Convert.ToDecimal(this.cinf.TotalPhysicalMemory) * 100),
                   2,
                   MidpointRounding.AwayFromZero);
        }

        public HardDiskInfo GetHardDiskInfoByName(string diskName)
        {
            DriveInfo drive = new DriveInfo(diskName);          
            return new HardDiskInfo { FreeSpace = GetDriveData(drive.AvailableFreeSpace),TotalSpace =GetDriveData (drive.TotalSize  ),Name =drive .Name  };
        }

        public IEnumerable<HardDiskInfo> GetAllHardDiskInfo()
        {
            List<HardDiskInfo> infos=new List<HardDiskInfo> ();
            foreach (var d in DriveInfo.GetDrives ())
            {
                if (d.IsReady)
                {
                    HardDiskInfo h = new HardDiskInfo
                                         {
                                             Name = d.Name,
                                             FreeSpace = GetDriveData(d.AvailableFreeSpace),
                                             TotalSpace = GetDriveData(d.TotalSize)
                                         };
                    infos.Add(h);
                }
               
            }
            return infos;
        }

        private string GetDriveData(long data)
        {
            return (data / Convert.ToDouble(1024) / Convert.ToDouble(1024) / Convert.ToDouble(1024)).ToString("0.00");
        }

        public void Dispose()
        {
            this.cpu.Dispose();
        }
    }
    class HardDiskInfo
	{
        public string Name { get; set; }
        public string   FreeSpace { get; set; }
        public string TotalSpace { get;set;}
	}
}
